# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: kumiho.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'kumiho.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ckumiho.proto\x12\x06kumiho\"\x13\n\x04Kref\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xf4\x01\n\x04\x45\x64ge\x12!\n\x0bsource_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12!\n\x0btarget_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x11\n\tedge_type\x18\x03 \x01(\t\x12,\n\x08metadata\x18\x04 \x03(\x0b\x32\x1a.kumiho.Edge.MetadataEntry\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x06 \x01(\t\x12\x10\n\x08username\x18\x07 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x0eStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"6\n\x11PaginationRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\t\"P\n\x12PaginationResponse\x12\x13\n\x0bnext_cursor\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\")\n\x0bKrefRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\"X\n\x12ResolveKrefRequest\x12\x0c\n\x04kref\x18\x01 \x01(\t\x12\x10\n\x03tag\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04time\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_tagB\x07\n\x05_time\"\\\n\x16ResolveLocationRequest\x12\x0c\n\x04kref\x18\x01 \x01(\t\x12\x10\n\x03tag\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04time\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_tagB\x07\n\x05_time\"g\n\x17ResolveLocationResponse\x12\x10\n\x08location\x18\x01 \x01(\t\x12#\n\rresolved_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x15\n\rartifact_name\x18\x03 \x01(\t\"S\n\x12\x43reateSpaceRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x12\n\nspace_name\x18\x02 \x01(\t\x12\x14\n\x0c\x65xists_error\x18\x03 \x01(\x08\"\xec\x01\n\rSpaceResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x13\n\x0bmodified_at\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x35\n\x08metadata\x18\x05 \x03(\x0b\x32#.kumiho.SpaceResponse.MetadataEntry\x12\x10\n\x08username\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x0fGetSpaceRequest\x12\x14\n\x0cpath_or_kref\x18\x01 \x01(\t\"1\n\x12\x44\x65leteSpaceRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\x82\x01\n\x15GetChildSpacesRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x32\n\npagination\x18\x03 \x01(\x0b\x32\x19.kumiho.PaginationRequestH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"\x83\x01\n\x16GetChildSpacesResponse\x12%\n\x06spaces\x18\x01 \x03(\x0b\x32\x15.kumiho.SpaceResponse\x12\x33\n\npagination\x18\x02 \x01(\x0b\x32\x1a.kumiho.PaginationResponseH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"_\n\x11\x43reateItemRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x11\n\titem_name\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x14\n\x0c\x65xists_error\x18\x04 \x01(\x08\"F\n\x0eGetItemRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x11\n\titem_name\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\"\x9f\x02\n\x0cItemResponse\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\titem_name\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x13\n\x0bmodified_at\x18\x06 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x07 \x01(\t\x12\x34\n\x08metadata\x18\x08 \x03(\x0b\x32\".kumiho.ItemResponse.MetadataEntry\x12\x12\n\ndeprecated\x18\t \x01(\x08\x12\x10\n\x08username\x18\n \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x11\x44\x65leteItemRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\xb4\x01\n\x0fGetItemsRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x18\n\x10item_name_filter\x18\x02 \x01(\t\x12\x13\n\x0bkind_filter\x18\x03 \x01(\t\x12\x32\n\npagination\x18\x04 \x01(\x0b\x32\x19.kumiho.PaginationRequestH\x00\x88\x01\x01\x12\x1a\n\x12include_deprecated\x18\x05 \x01(\x08\x42\r\n\x0b_pagination\"{\n\x10GetItemsResponse\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.kumiho.ItemResponse\x12\x33\n\npagination\x18\x02 \x01(\x0b\x32\x1a.kumiho.PaginationResponseH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"\xb9\x01\n\x11ItemSearchRequest\x12\x16\n\x0e\x63ontext_filter\x18\x01 \x01(\t\x12\x18\n\x10item_name_filter\x18\x02 \x01(\t\x12\x13\n\x0bkind_filter\x18\x03 \x01(\t\x12\x32\n\npagination\x18\x04 \x01(\x0b\x32\x19.kumiho.PaginationRequestH\x00\x88\x01\x01\x12\x1a\n\x12include_deprecated\x18\x05 \x01(\x08\x42\r\n\x0b_pagination\"\xce\x01\n\x15\x43reateRevisionRequest\x12\x1f\n\titem_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12=\n\x08metadata\x18\x02 \x03(\x0b\x32+.kumiho.CreateRevisionRequest.MetadataEntry\x12\x0e\n\x06number\x18\x03 \x01(\x05\x12\x14\n\x0c\x65xists_error\x18\x04 \x01(\x08\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x03\n\x10RevisionResponse\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x1f\n\titem_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0e\n\x06number\x18\x03 \x01(\x05\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x38\n\x08metadata\x18\x05 \x03(\x0b\x32&.kumiho.RevisionResponse.MetadataEntry\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x13\n\x0bmodified_at\x18\x07 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x08 \x01(\t\x12\x12\n\ndeprecated\x18\t \x01(\x08\x12\x11\n\tpublished\x18\n \x01(\x08\x12\x0e\n\x06latest\x18\x0b \x01(\x08\x12\x10\n\x08username\x18\x0c \x01(\t\x12\x1d\n\x10\x64\x65\x66\x61ult_artifact\x18\r \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x0e \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x13\n\x11_default_artifact\"B\n\x15\x44\x65leteRevisionRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"y\n\x13GetRevisionsRequest\x12\x1f\n\titem_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x32\n\npagination\x18\x02 \x01(\x0b\x32\x19.kumiho.PaginationRequestH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"\x87\x01\n\x14GetRevisionsResponse\x12+\n\trevisions\x18\x01 \x03(\x0b\x32\x18.kumiho.RevisionResponse\x12\x33\n\npagination\x18\x02 \x01(\x0b\x32\x1a.kumiho.PaginationResponseH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"\xe2\x01\n\x15\x43reateArtifactRequest\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x14\n\x0c\x65xists_error\x18\x04 \x01(\x08\x12=\n\x08metadata\x18\x05 \x03(\x0b\x32+.kumiho.CreateArtifactRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x02\n\x10\x41rtifactResponse\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x10\n\x08location\x18\x02 \x01(\t\x12#\n\rrevision_kref\x18\x03 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x1f\n\titem_kref\x18\x04 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x13\n\x0bmodified_at\x18\x06 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x07 \x01(\t\x12\x38\n\x08metadata\x18\x08 \x03(\x0b\x32&.kumiho.ArtifactResponse.MetadataEntry\x12\x12\n\ndeprecated\x18\t \x01(\x08\x12\x10\n\x08username\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n\x12GetArtifactRequest\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x13GetArtifactsRequest\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\"C\n\x14GetArtifactsResponse\x12+\n\tartifacts\x18\x01 \x03(\x0b\x32\x18.kumiho.ArtifactResponse\"B\n\x15\x44\x65leteArtifactRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"1\n\x1dGetArtifactsByLocationRequest\x12\x10\n\x08location\x18\x01 \x01(\t\"M\n\x1eGetArtifactsByLocationResponse\x12+\n\tartifacts\x18\x01 \x03(\x0b\x32\x18.kumiho.ArtifactResponse\"=\n\x12TagRevisionRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03tag\x18\x02 \x01(\t\"?\n\x14UnTagRevisionRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03tag\x18\x02 \x01(\t\"8\n\rHasTagRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03tag\x18\x02 \x01(\t\"!\n\x0eHasTagResponse\x12\x0f\n\x07has_tag\x18\x01 \x01(\x08\";\n\x10WasTaggedRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\'\n\x11WasTaggedResponse\x12\x12\n\nwas_tagged\x18\x01 \x01(\x08\"W\n\x19SetDefaultArtifactRequest\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x15\n\rartifact_name\x18\x02 \x01(\t\"\x80\x02\n\x11\x43reateEdgeRequest\x12*\n\x14source_revision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12*\n\x14target_revision_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x11\n\tedge_type\x18\x03 \x01(\t\x12\x39\n\x08metadata\x18\x04 \x03(\x0b\x32\'.kumiho.CreateEdgeRequest.MetadataEntry\x12\x14\n\x0c\x65xists_error\x18\x05 \x01(\x08\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x15UpdateMetadataRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12=\n\x08metadata\x18\x02 \x03(\x0b\x32+.kumiho.UpdateMetadataRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x13SetAttributeRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\">\n\x13GetAttributeRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03key\x18\x02 \x01(\t\"B\n\x14GetAttributeResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06\x65xists\x18\x03 \x01(\x08\"A\n\x16\x44\x65leteAttributeRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0b\n\x03key\x18\x02 \x01(\t\":\n\x17PeekNextRevisionRequest\x12\x1f\n\titem_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\"*\n\x18PeekNextRevisionResponse\x12\x0e\n\x06number\x18\x01 \x01(\x05\"\xb4\x01\n\x0fGetEdgesRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x18\n\x10\x65\x64ge_type_filter\x18\x02 \x01(\t\x12(\n\tdirection\x18\x03 \x01(\x0e\x32\x15.kumiho.EdgeDirection\x12\x32\n\npagination\x18\x04 \x01(\x0b\x32\x19.kumiho.PaginationRequestH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"\x99\x01\n\x10GetEdgesResponse\x12\x1b\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x0c.kumiho.Edge\x12$\n\x0erevision_krefs\x18\x02 \x03(\x0b\x32\x0c.kumiho.Kref\x12\x33\n\npagination\x18\x03 \x01(\x0b\x32\x1a.kumiho.PaginationResponseH\x00\x88\x01\x01\x42\r\n\x0b_pagination\"l\n\x11\x44\x65leteEdgeRequest\x12!\n\x0bsource_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12!\n\x0btarget_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x11\n\tedge_type\x18\x03 \x01(\t\"Q\n\x08PathStep\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x11\n\tedge_type\x18\x02 \x01(\t\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\x05\"D\n\x0cRevisionPath\x12\x1f\n\x05steps\x18\x01 \x03(\x0b\x32\x10.kumiho.PathStep\x12\x13\n\x0btotal_depth\x18\x02 \x01(\x05\"\xb5\x01\n\x14TraverseEdgesRequest\x12!\n\x0borigin_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12(\n\tdirection\x18\x02 \x01(\x0e\x32\x15.kumiho.EdgeDirection\x12\x18\n\x10\x65\x64ge_type_filter\x18\x03 \x03(\t\x12\x11\n\tmax_depth\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x14\n\x0cinclude_path\x18\x06 \x01(\x08\"\xa7\x01\n\x15TraverseEdgesResponse\x12#\n\x05paths\x18\x01 \x03(\x0b\x32\x14.kumiho.RevisionPath\x12$\n\x0erevision_krefs\x18\x02 \x03(\x0b\x32\x0c.kumiho.Kref\x12\x1b\n\x05\x65\x64ges\x18\x03 \x03(\x0b\x32\x0c.kumiho.Edge\x12\x13\n\x0btotal_count\x18\x04 \x01(\x05\x12\x11\n\ttruncated\x18\x05 \x01(\x08\"\x9e\x01\n\x13ShortestPathRequest\x12!\n\x0bsource_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12!\n\x0btarget_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x18\n\x10\x65\x64ge_type_filter\x18\x03 \x03(\t\x12\x11\n\tmax_depth\x18\x04 \x01(\x05\x12\x14\n\x0c\x61ll_shortest\x18\x05 \x01(\x08\"e\n\x14ShortestPathResponse\x12#\n\x05paths\x18\x01 \x03(\x0b\x32\x14.kumiho.RevisionPath\x12\x13\n\x0bpath_exists\x18\x02 \x01(\x08\x12\x13\n\x0bpath_length\x18\x03 \x01(\x05\"x\n\x15ImpactAnalysisRequest\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x18\n\x10\x65\x64ge_type_filter\x18\x02 \x03(\t\x12\x11\n\tmax_depth\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"\x89\x01\n\x10ImpactedRevision\x12#\n\rrevision_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x1f\n\titem_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x14\n\x0cimpact_depth\x18\x03 \x01(\x05\x12\x19\n\x11impact_path_types\x18\x04 \x03(\t\"y\n\x16ImpactAnalysisResponse\x12\x34\n\x12impacted_revisions\x18\x01 \x03(\x0b\x32\x18.kumiho.ImpactedRevision\x12\x16\n\x0etotal_impacted\x18\x02 \x01(\x05\x12\x11\n\ttruncated\x18\x03 \x01(\x08\"\xad\x01\n\x13\x43reateBundleRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x13\n\x0b\x62undle_name\x18\x02 \x01(\t\x12;\n\x08metadata\x18\x03 \x03(\x0b\x32).kumiho.CreateBundleRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x0c\x42undleMember\x12\x1f\n\titem_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x10\n\x08\x61\x64\x64\x65\x64_at\x18\x02 \x01(\t\x12\x10\n\x08\x61\x64\x64\x65\x64_by\x18\x03 \x01(\t\x12\x19\n\x11\x61\x64\x64\x65\x64_by_username\x18\x04 \x01(\t\x12\x19\n\x11\x61\x64\x64\x65\x64_in_revision\x18\x05 \x01(\x05\"\xd4\x01\n\x16\x41\x64\x64\x42undleMemberRequest\x12!\n\x0b\x62undle_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12&\n\x10member_item_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12>\n\x08metadata\x18\x03 \x03(\x0b\x32,.kumiho.AddBundleMemberRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x17\x41\x64\x64\x42undleMemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12.\n\x0cnew_revision\x18\x03 \x01(\x0b\x32\x18.kumiho.RevisionResponse\"\xda\x01\n\x19RemoveBundleMemberRequest\x12!\n\x0b\x62undle_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12&\n\x10member_item_kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x41\n\x08metadata\x18\x03 \x03(\x0b\x32/.kumiho.RemoveBundleMemberRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x1aRemoveBundleMemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12.\n\x0cnew_revision\x18\x03 \x01(\x0b\x32\x18.kumiho.RevisionResponse\"n\n\x17GetBundleMembersRequest\x12!\n\x0b\x62undle_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x1c\n\x0frevision_number\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\x12\n\x10_revision_number\"o\n\x18GetBundleMembersResponse\x12%\n\x07members\x18\x01 \x03(\x0b\x32\x14.kumiho.BundleMember\x12\x17\n\x0frevision_number\x18\x02 \x01(\x05\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\"\x8e\x02\n\x15\x42undleRevisionHistory\x12\x17\n\x0frevision_number\x18\x01 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12&\n\x10member_item_kref\x18\x03 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12=\n\x08metadata\x18\x07 \x03(\x0b\x32+.kumiho.BundleRevisionHistory.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x17GetBundleHistoryRequest\x12!\n\x0b\x62undle_kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\"J\n\x18GetBundleHistoryResponse\x12.\n\x07history\x18\x01 \x03(\x0b\x32\x1d.kumiho.BundleRevisionHistory\"\x89\x02\n\x12\x45ventStreamRequest\x12\x1a\n\x12routing_key_filter\x18\x01 \x01(\t\x12\x13\n\x0bkref_filter\x18\x02 \x01(\t\x12\x13\n\x06\x63ursor\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0e\x63onsumer_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x0b\x66rom_latest\x18\x05 \x01(\x08H\x00\x12\x15\n\x0b\x66rom_cursor\x18\x06 \x01(\tH\x00\x12\x18\n\x0e\x66rom_timestamp\x18\x07 \x01(\tH\x00\x12\x18\n\x0e\x66rom_beginning\x18\x08 \x01(\x08H\x00\x42\x10\n\x0estart_positionB\t\n\x07_cursorB\x11\n\x0f_consumer_group\"\xed\x01\n\x05\x45vent\x12\x13\n\x0brouting_key\x18\x01 \x01(\t\x12\x1a\n\x04kref\x18\x02 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x11\n\ttenant_id\x18\x05 \x01(\t\x12+\n\x07\x64\x65tails\x18\x06 \x03(\x0b\x32\x1a.kumiho.Event.DetailsEntry\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x08 \x01(\t\x1a.\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1d\n\x1bGetEventCapabilitiesRequest\"\xab\x01\n\x11\x45ventCapabilities\x12\x17\n\x0fsupports_replay\x18\x01 \x01(\x08\x12\x17\n\x0fsupports_cursor\x18\x02 \x01(\x08\x12 \n\x18supports_consumer_groups\x18\x03 \x01(\x08\x12\x1b\n\x13max_retention_hours\x18\x04 \x01(\x03\x12\x17\n\x0fmax_buffer_size\x18\x05 \x01(\x03\x12\x0c\n\x04tier\x18\x06 \x01(\t\"9\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x9a\x01\n\x0fProjectResponse\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\x12\x12\n\ndeprecated\x18\x06 \x01(\x08\x12\x14\n\x0c\x61llow_public\x18\x07 \x01(\x08\"\x14\n\x12GetProjectsRequest\"@\n\x13GetProjectsResponse\x12)\n\x08projects\x18\x01 \x03(\x0b\x32\x17.kumiho.ProjectResponse\"9\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\x80\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x19\n\x0c\x61llow_public\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_allow_publicB\x0e\n\x0c_description\"F\n\x14SetDeprecatedRequest\x12\x1a\n\x04kref\x18\x01 \x01(\x0b\x32\x0c.kumiho.Kref\x12\x12\n\ndeprecated\x18\x02 \x01(\x08\"\x17\n\x15GetTenantUsageRequest\"P\n\x13TenantUsageResponse\x12\x12\n\nnode_count\x18\x01 \x01(\x03\x12\x12\n\nnode_limit\x18\x02 \x01(\x03\x12\x11\n\ttenant_id\x18\x03 \x01(\t*5\n\rEdgeDirection\x12\x0c\n\x08OUTGOING\x10\x00\x12\x0c\n\x08INCOMING\x10\x01\x12\x08\n\x04\x42OTH\x10\x02\x32\xfd\x1d\n\rKumihoService\x12\x46\n\rCreateProject\x12\x1c.kumiho.CreateProjectRequest\x1a\x17.kumiho.ProjectResponse\x12\x46\n\x0bGetProjects\x12\x1a.kumiho.GetProjectsRequest\x1a\x1b.kumiho.GetProjectsResponse\x12\x46\n\rUpdateProject\x12\x1c.kumiho.UpdateProjectRequest\x1a\x17.kumiho.ProjectResponse\x12\x45\n\rDeleteProject\x12\x1c.kumiho.DeleteProjectRequest\x1a\x16.kumiho.StatusResponse\x12@\n\x0b\x43reateSpace\x12\x1a.kumiho.CreateSpaceRequest\x1a\x15.kumiho.SpaceResponse\x12:\n\x08GetSpace\x12\x17.kumiho.GetSpaceRequest\x1a\x15.kumiho.SpaceResponse\x12O\n\x0eGetChildSpaces\x12\x1d.kumiho.GetChildSpacesRequest\x1a\x1e.kumiho.GetChildSpacesResponse\x12\x41\n\x0b\x44\x65leteSpace\x12\x1a.kumiho.DeleteSpaceRequest\x1a\x16.kumiho.StatusResponse\x12K\n\x13UpdateSpaceMetadata\x12\x1d.kumiho.UpdateMetadataRequest\x1a\x15.kumiho.SpaceResponse\x12=\n\nCreateItem\x12\x19.kumiho.CreateItemRequest\x1a\x14.kumiho.ItemResponse\x12\x37\n\x07GetItem\x12\x16.kumiho.GetItemRequest\x1a\x14.kumiho.ItemResponse\x12=\n\x08GetItems\x12\x17.kumiho.GetItemsRequest\x1a\x18.kumiho.GetItemsResponse\x12\x41\n\nItemSearch\x12\x19.kumiho.ItemSearchRequest\x1a\x18.kumiho.GetItemsResponse\x12?\n\nDeleteItem\x12\x19.kumiho.DeleteItemRequest\x1a\x16.kumiho.StatusResponse\x12I\n\x12UpdateItemMetadata\x12\x1d.kumiho.UpdateMetadataRequest\x1a\x14.kumiho.ItemResponse\x12\x43\n\x0bResolveKref\x12\x1a.kumiho.ResolveKrefRequest\x1a\x18.kumiho.RevisionResponse\x12R\n\x0fResolveLocation\x12\x1e.kumiho.ResolveLocationRequest\x1a\x1f.kumiho.ResolveLocationResponse\x12I\n\x0e\x43reateRevision\x12\x1d.kumiho.CreateRevisionRequest\x1a\x18.kumiho.RevisionResponse\x12<\n\x0bGetRevision\x12\x13.kumiho.KrefRequest\x1a\x18.kumiho.RevisionResponse\x12I\n\x0cGetRevisions\x12\x1b.kumiho.GetRevisionsRequest\x1a\x1c.kumiho.GetRevisionsResponse\x12G\n\x0e\x44\x65leteRevision\x12\x1d.kumiho.DeleteRevisionRequest\x1a\x16.kumiho.StatusResponse\x12U\n\x10PeekNextRevision\x12\x1f.kumiho.PeekNextRevisionRequest\x1a .kumiho.PeekNextRevisionResponse\x12Q\n\x16UpdateRevisionMetadata\x12\x1d.kumiho.UpdateMetadataRequest\x1a\x18.kumiho.RevisionResponse\x12\x41\n\x0bTagRevision\x12\x1a.kumiho.TagRevisionRequest\x1a\x16.kumiho.StatusResponse\x12\x45\n\rUnTagRevision\x12\x1c.kumiho.UnTagRevisionRequest\x1a\x16.kumiho.StatusResponse\x12\x37\n\x06HasTag\x12\x15.kumiho.HasTagRequest\x1a\x16.kumiho.HasTagResponse\x12@\n\tWasTagged\x12\x18.kumiho.WasTaggedRequest\x1a\x19.kumiho.WasTaggedResponse\x12O\n\x12SetDefaultArtifact\x12!.kumiho.SetDefaultArtifactRequest\x1a\x16.kumiho.StatusResponse\x12I\n\x0e\x43reateArtifact\x12\x1d.kumiho.CreateArtifactRequest\x1a\x18.kumiho.ArtifactResponse\x12\x43\n\x0bGetArtifact\x12\x1a.kumiho.GetArtifactRequest\x1a\x18.kumiho.ArtifactResponse\x12I\n\x0cGetArtifacts\x12\x1b.kumiho.GetArtifactsRequest\x1a\x1c.kumiho.GetArtifactsResponse\x12g\n\x16GetArtifactsByLocation\x12%.kumiho.GetArtifactsByLocationRequest\x1a&.kumiho.GetArtifactsByLocationResponse\x12G\n\x0e\x44\x65leteArtifact\x12\x1d.kumiho.DeleteArtifactRequest\x1a\x16.kumiho.StatusResponse\x12Q\n\x16UpdateArtifactMetadata\x12\x1d.kumiho.UpdateMetadataRequest\x1a\x18.kumiho.ArtifactResponse\x12\x43\n\x0cSetAttribute\x12\x1b.kumiho.SetAttributeRequest\x1a\x16.kumiho.StatusResponse\x12I\n\x0cGetAttribute\x12\x1b.kumiho.GetAttributeRequest\x1a\x1c.kumiho.GetAttributeResponse\x12I\n\x0f\x44\x65leteAttribute\x12\x1e.kumiho.DeleteAttributeRequest\x1a\x16.kumiho.StatusResponse\x12?\n\nCreateEdge\x12\x19.kumiho.CreateEdgeRequest\x1a\x16.kumiho.StatusResponse\x12=\n\x08GetEdges\x12\x17.kumiho.GetEdgesRequest\x1a\x18.kumiho.GetEdgesResponse\x12?\n\nDeleteEdge\x12\x19.kumiho.DeleteEdgeRequest\x1a\x16.kumiho.StatusResponse\x12L\n\rTraverseEdges\x12\x1c.kumiho.TraverseEdgesRequest\x1a\x1d.kumiho.TraverseEdgesResponse\x12M\n\x10\x46indShortestPath\x12\x1b.kumiho.ShortestPathRequest\x1a\x1c.kumiho.ShortestPathResponse\x12N\n\rAnalyzeImpact\x12\x1d.kumiho.ImpactAnalysisRequest\x1a\x1e.kumiho.ImpactAnalysisResponse\x12\x41\n\x0c\x43reateBundle\x12\x1b.kumiho.CreateBundleRequest\x1a\x14.kumiho.ItemResponse\x12R\n\x0f\x41\x64\x64\x42undleMember\x12\x1e.kumiho.AddBundleMemberRequest\x1a\x1f.kumiho.AddBundleMemberResponse\x12[\n\x12RemoveBundleMember\x12!.kumiho.RemoveBundleMemberRequest\x1a\".kumiho.RemoveBundleMemberResponse\x12U\n\x10GetBundleMembers\x12\x1f.kumiho.GetBundleMembersRequest\x1a .kumiho.GetBundleMembersResponse\x12U\n\x10GetBundleHistory\x12\x1f.kumiho.GetBundleHistoryRequest\x1a .kumiho.GetBundleHistoryResponse\x12L\n\x0eGetTenantUsage\x12\x1d.kumiho.GetTenantUsageRequest\x1a\x1b.kumiho.TenantUsageResponse\x12:\n\x0b\x45ventStream\x12\x1a.kumiho.EventStreamRequest\x1a\r.kumiho.Event0\x01\x12V\n\x14GetEventCapabilities\x12#.kumiho.GetEventCapabilitiesRequest\x1a\x19.kumiho.EventCapabilities\x12\x45\n\rSetDeprecated\x12\x1c.kumiho.SetDeprecatedRequest\x1a\x16.kumiho.StatusResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kumiho_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EDGE_METADATAENTRY']._loaded_options = None
  _globals['_EDGE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SPACERESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_SPACERESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ITEMRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_ITEMRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREVISIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEREVISIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REVISIONRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_REVISIONRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEARTIFACTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEARTIFACTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ARTIFACTRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_ARTIFACTRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEEDGEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEEDGEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEMETADATAREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEMETADATAREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBUNDLEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEBUNDLEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ADDBUNDLEMEMBERREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_ADDBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REMOVEBUNDLEMEMBERREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_REMOVEBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BUNDLEREVISIONHISTORY_METADATAENTRY']._loaded_options = None
  _globals['_BUNDLEREVISIONHISTORY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENT_DETAILSENTRY']._loaded_options = None
  _globals['_EVENT_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_EDGEDIRECTION']._serialized_start=10270
  _globals['_EDGEDIRECTION']._serialized_end=10323
  _globals['_KREF']._serialized_start=24
  _globals['_KREF']._serialized_end=43
  _globals['_EDGE']._serialized_start=46
  _globals['_EDGE']._serialized_end=290
  _globals['_EDGE_METADATAENTRY']._serialized_start=243
  _globals['_EDGE_METADATAENTRY']._serialized_end=290
  _globals['_STATUSRESPONSE']._serialized_start=292
  _globals['_STATUSRESPONSE']._serialized_end=342
  _globals['_PAGINATIONREQUEST']._serialized_start=344
  _globals['_PAGINATIONREQUEST']._serialized_end=398
  _globals['_PAGINATIONRESPONSE']._serialized_start=400
  _globals['_PAGINATIONRESPONSE']._serialized_end=480
  _globals['_KREFREQUEST']._serialized_start=482
  _globals['_KREFREQUEST']._serialized_end=523
  _globals['_RESOLVEKREFREQUEST']._serialized_start=525
  _globals['_RESOLVEKREFREQUEST']._serialized_end=613
  _globals['_RESOLVELOCATIONREQUEST']._serialized_start=615
  _globals['_RESOLVELOCATIONREQUEST']._serialized_end=707
  _globals['_RESOLVELOCATIONRESPONSE']._serialized_start=709
  _globals['_RESOLVELOCATIONRESPONSE']._serialized_end=812
  _globals['_CREATESPACEREQUEST']._serialized_start=814
  _globals['_CREATESPACEREQUEST']._serialized_end=897
  _globals['_SPACERESPONSE']._serialized_start=900
  _globals['_SPACERESPONSE']._serialized_end=1136
  _globals['_SPACERESPONSE_METADATAENTRY']._serialized_start=243
  _globals['_SPACERESPONSE_METADATAENTRY']._serialized_end=290
  _globals['_GETSPACEREQUEST']._serialized_start=1138
  _globals['_GETSPACEREQUEST']._serialized_end=1177
  _globals['_DELETESPACEREQUEST']._serialized_start=1179
  _globals['_DELETESPACEREQUEST']._serialized_end=1228
  _globals['_GETCHILDSPACESREQUEST']._serialized_start=1231
  _globals['_GETCHILDSPACESREQUEST']._serialized_end=1361
  _globals['_GETCHILDSPACESRESPONSE']._serialized_start=1364
  _globals['_GETCHILDSPACESRESPONSE']._serialized_end=1495
  _globals['_CREATEITEMREQUEST']._serialized_start=1497
  _globals['_CREATEITEMREQUEST']._serialized_end=1592
  _globals['_GETITEMREQUEST']._serialized_start=1594
  _globals['_GETITEMREQUEST']._serialized_end=1664
  _globals['_ITEMRESPONSE']._serialized_start=1667
  _globals['_ITEMRESPONSE']._serialized_end=1954
  _globals['_ITEMRESPONSE_METADATAENTRY']._serialized_start=243
  _globals['_ITEMRESPONSE_METADATAENTRY']._serialized_end=290
  _globals['_DELETEITEMREQUEST']._serialized_start=1956
  _globals['_DELETEITEMREQUEST']._serialized_end=2018
  _globals['_GETITEMSREQUEST']._serialized_start=2021
  _globals['_GETITEMSREQUEST']._serialized_end=2201
  _globals['_GETITEMSRESPONSE']._serialized_start=2203
  _globals['_GETITEMSRESPONSE']._serialized_end=2326
  _globals['_ITEMSEARCHREQUEST']._serialized_start=2329
  _globals['_ITEMSEARCHREQUEST']._serialized_end=2514
  _globals['_CREATEREVISIONREQUEST']._serialized_start=2517
  _globals['_CREATEREVISIONREQUEST']._serialized_end=2723
  _globals['_CREATEREVISIONREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_CREATEREVISIONREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_REVISIONRESPONSE']._serialized_start=2726
  _globals['_REVISIONRESPONSE']._serialized_end=3138
  _globals['_REVISIONRESPONSE_METADATAENTRY']._serialized_start=243
  _globals['_REVISIONRESPONSE_METADATAENTRY']._serialized_end=290
  _globals['_DELETEREVISIONREQUEST']._serialized_start=3140
  _globals['_DELETEREVISIONREQUEST']._serialized_end=3206
  _globals['_GETREVISIONSREQUEST']._serialized_start=3208
  _globals['_GETREVISIONSREQUEST']._serialized_end=3329
  _globals['_GETREVISIONSRESPONSE']._serialized_start=3332
  _globals['_GETREVISIONSRESPONSE']._serialized_end=3467
  _globals['_CREATEARTIFACTREQUEST']._serialized_start=3470
  _globals['_CREATEARTIFACTREQUEST']._serialized_end=3696
  _globals['_CREATEARTIFACTREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_CREATEARTIFACTREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_ARTIFACTRESPONSE']._serialized_start=3699
  _globals['_ARTIFACTRESPONSE']._serialized_end=4049
  _globals['_ARTIFACTRESPONSE_METADATAENTRY']._serialized_start=243
  _globals['_ARTIFACTRESPONSE_METADATAENTRY']._serialized_end=290
  _globals['_GETARTIFACTREQUEST']._serialized_start=4051
  _globals['_GETARTIFACTREQUEST']._serialized_end=4122
  _globals['_GETARTIFACTSREQUEST']._serialized_start=4124
  _globals['_GETARTIFACTSREQUEST']._serialized_end=4182
  _globals['_GETARTIFACTSRESPONSE']._serialized_start=4184
  _globals['_GETARTIFACTSRESPONSE']._serialized_end=4251
  _globals['_DELETEARTIFACTREQUEST']._serialized_start=4253
  _globals['_DELETEARTIFACTREQUEST']._serialized_end=4319
  _globals['_GETARTIFACTSBYLOCATIONREQUEST']._serialized_start=4321
  _globals['_GETARTIFACTSBYLOCATIONREQUEST']._serialized_end=4370
  _globals['_GETARTIFACTSBYLOCATIONRESPONSE']._serialized_start=4372
  _globals['_GETARTIFACTSBYLOCATIONRESPONSE']._serialized_end=4449
  _globals['_TAGREVISIONREQUEST']._serialized_start=4451
  _globals['_TAGREVISIONREQUEST']._serialized_end=4512
  _globals['_UNTAGREVISIONREQUEST']._serialized_start=4514
  _globals['_UNTAGREVISIONREQUEST']._serialized_end=4577
  _globals['_HASTAGREQUEST']._serialized_start=4579
  _globals['_HASTAGREQUEST']._serialized_end=4635
  _globals['_HASTAGRESPONSE']._serialized_start=4637
  _globals['_HASTAGRESPONSE']._serialized_end=4670
  _globals['_WASTAGGEDREQUEST']._serialized_start=4672
  _globals['_WASTAGGEDREQUEST']._serialized_end=4731
  _globals['_WASTAGGEDRESPONSE']._serialized_start=4733
  _globals['_WASTAGGEDRESPONSE']._serialized_end=4772
  _globals['_SETDEFAULTARTIFACTREQUEST']._serialized_start=4774
  _globals['_SETDEFAULTARTIFACTREQUEST']._serialized_end=4861
  _globals['_CREATEEDGEREQUEST']._serialized_start=4864
  _globals['_CREATEEDGEREQUEST']._serialized_end=5120
  _globals['_CREATEEDGEREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_CREATEEDGEREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_UPDATEMETADATAREQUEST']._serialized_start=5123
  _globals['_UPDATEMETADATAREQUEST']._serialized_end=5286
  _globals['_UPDATEMETADATAREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_UPDATEMETADATAREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_SETATTRIBUTEREQUEST']._serialized_start=5288
  _globals['_SETATTRIBUTEREQUEST']._serialized_end=5365
  _globals['_GETATTRIBUTEREQUEST']._serialized_start=5367
  _globals['_GETATTRIBUTEREQUEST']._serialized_end=5429
  _globals['_GETATTRIBUTERESPONSE']._serialized_start=5431
  _globals['_GETATTRIBUTERESPONSE']._serialized_end=5497
  _globals['_DELETEATTRIBUTEREQUEST']._serialized_start=5499
  _globals['_DELETEATTRIBUTEREQUEST']._serialized_end=5564
  _globals['_PEEKNEXTREVISIONREQUEST']._serialized_start=5566
  _globals['_PEEKNEXTREVISIONREQUEST']._serialized_end=5624
  _globals['_PEEKNEXTREVISIONRESPONSE']._serialized_start=5626
  _globals['_PEEKNEXTREVISIONRESPONSE']._serialized_end=5668
  _globals['_GETEDGESREQUEST']._serialized_start=5671
  _globals['_GETEDGESREQUEST']._serialized_end=5851
  _globals['_GETEDGESRESPONSE']._serialized_start=5854
  _globals['_GETEDGESRESPONSE']._serialized_end=6007
  _globals['_DELETEEDGEREQUEST']._serialized_start=6009
  _globals['_DELETEEDGEREQUEST']._serialized_end=6117
  _globals['_PATHSTEP']._serialized_start=6119
  _globals['_PATHSTEP']._serialized_end=6200
  _globals['_REVISIONPATH']._serialized_start=6202
  _globals['_REVISIONPATH']._serialized_end=6270
  _globals['_TRAVERSEEDGESREQUEST']._serialized_start=6273
  _globals['_TRAVERSEEDGESREQUEST']._serialized_end=6454
  _globals['_TRAVERSEEDGESRESPONSE']._serialized_start=6457
  _globals['_TRAVERSEEDGESRESPONSE']._serialized_end=6624
  _globals['_SHORTESTPATHREQUEST']._serialized_start=6627
  _globals['_SHORTESTPATHREQUEST']._serialized_end=6785
  _globals['_SHORTESTPATHRESPONSE']._serialized_start=6787
  _globals['_SHORTESTPATHRESPONSE']._serialized_end=6888
  _globals['_IMPACTANALYSISREQUEST']._serialized_start=6890
  _globals['_IMPACTANALYSISREQUEST']._serialized_end=7010
  _globals['_IMPACTEDREVISION']._serialized_start=7013
  _globals['_IMPACTEDREVISION']._serialized_end=7150
  _globals['_IMPACTANALYSISRESPONSE']._serialized_start=7152
  _globals['_IMPACTANALYSISRESPONSE']._serialized_end=7273
  _globals['_CREATEBUNDLEREQUEST']._serialized_start=7276
  _globals['_CREATEBUNDLEREQUEST']._serialized_end=7449
  _globals['_CREATEBUNDLEREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_CREATEBUNDLEREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_BUNDLEMEMBER']._serialized_start=7452
  _globals['_BUNDLEMEMBER']._serialized_end=7589
  _globals['_ADDBUNDLEMEMBERREQUEST']._serialized_start=7592
  _globals['_ADDBUNDLEMEMBERREQUEST']._serialized_end=7804
  _globals['_ADDBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_ADDBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_ADDBUNDLEMEMBERRESPONSE']._serialized_start=7806
  _globals['_ADDBUNDLEMEMBERRESPONSE']._serialized_end=7913
  _globals['_REMOVEBUNDLEMEMBERREQUEST']._serialized_start=7916
  _globals['_REMOVEBUNDLEMEMBERREQUEST']._serialized_end=8134
  _globals['_REMOVEBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_start=243
  _globals['_REMOVEBUNDLEMEMBERREQUEST_METADATAENTRY']._serialized_end=290
  _globals['_REMOVEBUNDLEMEMBERRESPONSE']._serialized_start=8136
  _globals['_REMOVEBUNDLEMEMBERRESPONSE']._serialized_end=8246
  _globals['_GETBUNDLEMEMBERSREQUEST']._serialized_start=8248
  _globals['_GETBUNDLEMEMBERSREQUEST']._serialized_end=8358
  _globals['_GETBUNDLEMEMBERSRESPONSE']._serialized_start=8360
  _globals['_GETBUNDLEMEMBERSRESPONSE']._serialized_end=8471
  _globals['_BUNDLEREVISIONHISTORY']._serialized_start=8474
  _globals['_BUNDLEREVISIONHISTORY']._serialized_end=8744
  _globals['_BUNDLEREVISIONHISTORY_METADATAENTRY']._serialized_start=243
  _globals['_BUNDLEREVISIONHISTORY_METADATAENTRY']._serialized_end=290
  _globals['_GETBUNDLEHISTORYREQUEST']._serialized_start=8746
  _globals['_GETBUNDLEHISTORYREQUEST']._serialized_end=8806
  _globals['_GETBUNDLEHISTORYRESPONSE']._serialized_start=8808
  _globals['_GETBUNDLEHISTORYRESPONSE']._serialized_end=8882
  _globals['_EVENTSTREAMREQUEST']._serialized_start=8885
  _globals['_EVENTSTREAMREQUEST']._serialized_end=9150
  _globals['_EVENT']._serialized_start=9153
  _globals['_EVENT']._serialized_end=9390
  _globals['_EVENT_DETAILSENTRY']._serialized_start=9344
  _globals['_EVENT_DETAILSENTRY']._serialized_end=9390
  _globals['_GETEVENTCAPABILITIESREQUEST']._serialized_start=9392
  _globals['_GETEVENTCAPABILITIESREQUEST']._serialized_end=9421
  _globals['_EVENTCAPABILITIES']._serialized_start=9424
  _globals['_EVENTCAPABILITIES']._serialized_end=9595
  _globals['_CREATEPROJECTREQUEST']._serialized_start=9597
  _globals['_CREATEPROJECTREQUEST']._serialized_end=9654
  _globals['_PROJECTRESPONSE']._serialized_start=9657
  _globals['_PROJECTRESPONSE']._serialized_end=9811
  _globals['_GETPROJECTSREQUEST']._serialized_start=9813
  _globals['_GETPROJECTSREQUEST']._serialized_end=9833
  _globals['_GETPROJECTSRESPONSE']._serialized_start=9835
  _globals['_GETPROJECTSRESPONSE']._serialized_end=9899
  _globals['_DELETEPROJECTREQUEST']._serialized_start=9901
  _globals['_DELETEPROJECTREQUEST']._serialized_end=9958
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=9961
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=10089
  _globals['_SETDEPRECATEDREQUEST']._serialized_start=10091
  _globals['_SETDEPRECATEDREQUEST']._serialized_end=10161
  _globals['_GETTENANTUSAGEREQUEST']._serialized_start=10163
  _globals['_GETTENANTUSAGEREQUEST']._serialized_end=10186
  _globals['_TENANTUSAGERESPONSE']._serialized_start=10188
  _globals['_TENANTUSAGERESPONSE']._serialized_end=10268
  _globals['_KUMIHOSERVICE']._serialized_start=10326
  _globals['_KUMIHOSERVICE']._serialized_end=14163
# @@protoc_insertion_point(module_scope)
